@@ -1,6 +1,6 @@
 #include <gtk/gtk.h>
 
-// FIXME: global vars !?
+/* FIXME: global vars !? */
 
 #define STR_SIZE 255
 #define ARGV_SIZE 10
@@ -9,7 +9,7 @@
 void
 create_tags 			       ();
 
-void
+gboolean
 open_hspell_pipe                       ();
 
 void
@@ -21,8 +21,6 @@ set_argv                           ();
 void
 set_def_argv                           ();
 
-// std...
-
 void
 on_suggest_checkbutton_toggled         (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
